library(tidyverse)
library(readr)
library(readxl)
library(writexl)
options(scipen = 999)

# averaging length in s
l <- 180

# get files
temp <- list.files(pattern = "*.CSV")
mod <- read_xlsx("modality.xlsx")

subjects <- c()
overview <- c()
x <- 1
for (i in 1:length(temp)) {

  # import data and rearrange columns
  HR <- read_csv(temp[x])
  HR <- HR[-c(1, 2), 3]
  colnames(HR) <- "HR"
  
  # extract subject name
  subject <- paste(substr(temp[x], 0, nchar(temp[x])-7))
  subjects <- c(subjects, subject)
  
  line <- which(mod$subject == subject)
  
  # find order of condition
  modality <- mod$modality[line]

  # cutting into conditions
  First <- HR[c(181:780), ]
  Second <- HR[c(1081:1680), ]
  Third <- HR[c(1981:2580), ]
  Fourth <- HR[c(2881:3480), ]
  
  # use last three minutes for further analyses
  First <- tail(First, n = l)
  Second <- tail(Second, n = l)
  Third <- tail(Third, n = l)
  Fourth <- tail(Fourth, n = l)
 
    First <- transform(First, 
                       `HR` = as.double(`HR`))
    Second <- transform(Second, 
                       `HR` = as.double(`HR`))
    Third <- transform(Third, 
                       `HR` = as.double(`HR`))
    Fourth <- transform(Fourth, 
                       `HR` = as.double(`HR`))
    
  # calculate mean values
  means_01 <- c(mean(First$HR))
  means_02 <- c(mean(Second$HR))
    
  if (modality == "CON-EMS") {
    means_03 <- c(mean(Third$HR))
    means_04 <- c(mean(Fourth$HR))
  } else {
    means_04 <- c(mean(Third$HR))
    means_03 <- c(mean(Fourth$HR))
  }

  all_means <- c(means_01, means_02, means_03, means_04)
  overview <- rbind(overview, all_means)
  overview <- as.data.frame((overview))

  x <- x + 1
}

overview <- cbind(subjects, overview)
colnames(overview) <- c("Subject", "CON_REST", "EMS_REST", "CON_LOAD", "EMS_LOAD")
rownames(overview) <- NULL

# clear environment
rm(list=setdiff(ls(), c("overview")))

# write file with mean values
write.xlsx(overview, "mean_values/heart_rate.xlsx")

