library(tidyverse)
library(readr)
library(readxl)
library(writexl)
library(openxlsx)
options(scipen = 999)

# averaging length
l <- 180

# get files
temp_xlsx <- list.files(pattern = "*.xlsx")

subjects <- c()
overview <- c()
x <- 1
for (i in 1:length(temp_xlsx)) {

  # import data and rearrange columns
  Spiro <- read_xlsx(temp_xlsx[x])
  modality <- as.character(Spiro[9, 2])
  Spiro <- Spiro[, c(4, 8, 10, 11, 12, 13, 15, 20)]
  Spiro <- Spiro[c(-1), ]
  
  # correct time vector (starting with - 30 due to REST measurement)
  y <- -30
  vector_time <- c()
  for (i in 1:length(Spiro$Zeit)) {
    vector_time <- c(vector_time, y)
    y <- y + 1
  }
  Spiro$Zeit <- vector_time
  
  # change columnnames and transform column format to double for calculations
  colnames(Spiro) <- c("time_spiro", "VE", "VO2", "rel_VO2", "VE/VO2", "VCO2", "RER", "BF")
  Spiro <- transform(Spiro, 
                     time_spiro = as.double(time_spiro),
                     VE = as.double(VE),
                     VO2 = as.double(VO2),
                     rel_VO2 = as.double(rel_VO2),
                     `VE/VO2` = as.double(`VE/VO2`),
                     VCO2 = as.double(VCO2),
                     RER = as.double(RER),
                     BF = as.double(BF))

  # cutting into conditions
  First <- Spiro[c(212:811), ]
  Second <- Spiro[c(1112:1711), ]
  Third <- Spiro[c(2012:2611), ]
  Fourth <- Spiro[c(2912:3511), ]
  
  # use last three minutes for further calculations
  First <- tail(First, n = l)
  Second <- tail(Second, n = l)
  Third <- tail(Third, n = l)
  Fourth <- tail(Fourth, n = l)
  
  # fill vector

  means_01 <- c(mean(First$VE), mean(First$rel_VO2), mean(First$VO2), mean(First$VCO2), mean(First$RER),  mean(First$BF))
  means_02 <- c(mean(Second$VE), mean(Second$rel_VO2), mean(Second$VO2), mean(Second$VCO2), mean(Second$RER),  mean(Second$BF))
  
  if (modality == "CON-EMS") {
    means_03 <- c(mean(Third$VE), mean(Third$rel_VO2), mean(Third$VO2), mean(Third$VCO2), mean(Third$RER),  mean(Third$BF))
    means_04 <- c(mean(Fourth$VE), mean(Fourth$rel_VO2), mean(Fourth$VO2), mean(Fourth$VCO2), mean(Fourth$RER),  mean(Fourth$BF))
  } else {
    means_04 <- c(mean(Third$VE), mean(Third$rel_VO2), mean(Third$VO2), mean(Third$VCO2), mean(Third$RER),  mean(Third$BF))
    means_03 <- c(mean(Fourth$VE), mean(Fourth$rel_VO2), mean(Fourth$VO2), mean(Fourth$VCO2), mean(Fourth$RER),  mean(Fourth$BF))
  }

  all_means <- c(means_01, means_02, means_03, means_04)
  overview <- rbind(overview, all_means)
  overview <- as.data.frame((overview))
  
  # extract subject name
  subject <- paste(substr(temp_xlsx[x], 0, nchar(temp_xlsx[x])-5))
  subjects <- c(subjects, subject)

  x <- x + 1
}

overview <- cbind(subjects, overview)
colnames(overview) <- c("Subject", "CON_REST_VE", "CON_REST_rel_VO2", "CON_REST_VO2", "CON_REST_VCO2", "CON_REST_RER", "CON_REST_BF",
                        "EMS_REST_VE", "EMS_REST_rel_VO2", "EMS_REST_VO2", "EMS_REST_VCO2", "EMS_REST_RER", "EMS_REST_BF",
                        "CON_LOAD_VE", "CON_LOAD_rel_VO2", "CON_LOAD_VO2", "CON_LOAD_VCO2", "CON_LOAD_RER", "CON_LOAD_BF",
                        "EMS_LOAD_VE", "EMS_LOAD_rel_VO2", "EMS_LOAD_VO2", "EMS_LOAD_VCO2", "EMS_LOAD_RER", "EMS_LOAD_BF")
overview <- overview[, c(1, 3, 9, 15, 21, 4, 10, 16, 22, 5, 11, 17, 23, 6, 12, 18, 24, 2, 8, 14, 20, 7, 13, 19, 25)]
rownames(overview) <- c()

rm(list=setdiff(ls(), c("overview")))

write.xlsx(overview, "mean_values/Spirometric_data.xlsx")


